const { createSelectorCreator } = require('reselect')
const LRU = require('lru')

const hashFn = (...args) =>
  args.reduce((acc, val) => acc + '-' + JSON.stringify(val), '')

module.exports = createSelectorCreator(fn => {
  const cache = new LRU(10)

  return function () {
    const argumentHash = hashFn.apply(null, arguments)
    if (cache.get(argumentHash)) {
      return cache.get(argumentHash)
    }

    const val = fn.apply(null, arguments)
    cache.set(argumentHash, val)
    return val
  }
})
